clc; close all; clear all;
warning('off', 'all');

%==============================================================================%
% Section 1: Define basic variables                                            %
%==============================================================================%

PlotReceivers   = [1, 2];             % Results for this receiver will be plotted
PlotFrequencies = [125, 500, 2000];   % Results for this frequency will be plotted
GraphFraction   = 0.6;                % The legend may hide data points if GraphFraction is greater than, say, 0.8.
FileLocation    = '';                 % Location of the data file
FileName        = '';                 % Name of the data file. Remember the .txt extension!
ParameterName   = '';                 % Choose either 'EDT', 'T(20)', 'xi(T(20))', 'T(30)', 'xi(T(30))', 'Curvature', 'Ts',
                                      %               'G', 'G(early)', 'G(late)', 'C(80)', 'MTI(corrected)', 'LF(80)', 'LFC(80)',
                                      %               'Diffusivity', 'Echo(Dietsch)', 'STI', 'STI(Female)' or 'STI(Male)'


%==============================================================================%
% Section 2: Read data from file                                               %
%==============================================================================%

% Read data
[SourceList, ReceiverList, FrequencyList, ParamSim, ParamMeas, ParamJND, ParamExists] = ReadSimulatedAndMeasuredParameters(ParameterName, FileName, FileLocation);

% Compute the indices of the receiver and frequency to be plotted
[ReceiverIndices, ReceiversExist, FrequencyIndices, FrequenciesExist] = GetReceiverAndFrequencyIndices(PlotReceivers, ReceiverList, PlotFrequencies, FrequencyList);


% End the program if the chosen parameter, receivers or frequencies do not exist
ParamExists
ReceiversExist
FrequenciesExist
if strcmpi(ParamExists, 'No') | strcmpi(ReceiversExist, 'No') | strcmpi(FrequenciesExist, 'No')
  return;
end


%==============================================================================%
% Section 3: Plot data                                                         %
%==============================================================================%

if (~ strcmpi(ParameterName, 'STI')) & (~ strcmpi(ParameterName, 'STI(Female)')) & (~ strcmpi(ParameterName, 'STI(Male)'))
  % Plot the simulated and measured values of the parameter as a function of frequency for the chosen receiver
  for n = 1:length(PlotReceivers)
    figure(n)
    semilogx(FrequencyList, ParamSim(ReceiverIndices(n),:), 'k--o', 'LineWidth', 2)
    hold on
    semilogx(FrequencyList, ParamMeas(ReceiverIndices(n),:), 'r--x', 'LineWidth', 2)

    xlabel('Frequency (Hz)')
    ylabel(GetYLabel(ParameterName));

    ParamMax   = max(max(ParamSim(ReceiverIndices(n),:)), max(ParamMeas(ReceiverIndices(n),:)))
    ParamMin   = min(min(ParamSim(ReceiverIndices(n),:)), min(ParamMeas(ReceiverIndices(n),:)))
    GraphWidth = ParamMax - ParamMin;
    PlotWidth  = GraphWidth/GraphFraction;
    xlim([50, 10000])
    ylim([0.5*(ParamMax + ParamMin - PlotWidth), 0.5*(ParamMax + ParamMin + PlotWidth)])
    grid on

    set(gca, 'xtick', FrequencyList);
    set(gca, 'xticklabel',({'63', '125', '250', '500', '1000', '2000', '4000', '8000'}));
    set(gca, 'FontSize', 14)
    title(['Receiver ', num2str(PlotReceivers(n))], 'Interpreter', 'latex', 'FontSize', 20);
    legend1 = legend('Simulation', 'Measurement', 'Interpreter', 'Latex', 'FontSize', 14)
    %Uncomment the following line to change the position of the legend. Choose either "north", "south", "east", "west", "northeast", "northwest", "southeast", "southwest" or "outside"
    %legend(legend1, "location", 'north')
  end


  % Plot the difference of the simulated and measured parameter in units of JNDs as a function of frequency
  for n = 1:length(PlotReceivers)
    figure(length(PlotReceivers)+n)
    semilogx(FrequencyList, ParamJND(ReceiverIndices(n),:), 'k--o', 'LineWidth', 2)

    xlabel('Frequency (Hz)');
    ylabel('Difference (JND)');

    ParamJNDMax = max(ParamJND(ReceiverIndices(n),:));
    ParamJNDMin = min(ParamJND(ReceiverIndices(n),:));
    GraphWidth = ParamJNDMax - ParamJNDMin;
    PlotWidth  = GraphWidth/GraphFraction;
    xlim([50, 10000]);
    ylim([0.5*(ParamJNDMax + ParamJNDMin - PlotWidth), 0.5*(ParamJNDMax + ParamJNDMin + PlotWidth)]);
    grid on

    set(gca, 'xtick', FrequencyList);
    set(gca, 'xticklabel',({'63', '125', '250', '500', '1000', '2000', '4000', '8000'}));
    set(gca, 'FontSize', 14)
    title(['Receiver ', num2str(PlotReceivers(n))], 'Interpreter', 'latex', 'FontSize', 20);
  end


  % Plot the simulated and measured parameter values for the chosen frequency at the different receiver positions
  xList = 1:length(PlotReceivers);
  xTickLabels = {};
  for n = 1:length(PlotReceivers)
    xTickLabels{n} = ['R' num2str(PlotReceivers(n))];
  end

  figure(2*length(PlotReceivers)+1)
  for n = 1:length(FrequencyIndices)
    subplot(1, length(FrequencyIndices), n)
    plot(xList, ParamSim(ReceiverIndices, FrequencyIndices(n)), 'ko', 'LineWidth', 2)
    hold on
    plot(xList, ParamMeas(ReceiverIndices, FrequencyIndices(n)), 'rx', 'LineWidth', 2)

    if (n == 1)
      ylabel(GetYLabel(ParameterName));
    end
    set(gca, 'xtick', xList);
    set(gca, 'xticklabel',xTickLabels);
    set(gca, 'FontSize', 14)
    grid on

    ParamMax = max(max(ParamSim(ReceiverIndices, FrequencyIndices(n))), max(ParamMeas(ReceiverIndices, FrequencyIndices(n))))
    ParamMin = min(min(ParamSim(ReceiverIndices, FrequencyIndices(n))), min(ParamMeas(ReceiverIndices, FrequencyIndices(n))))
    GraphWidth = ParamMax - ParamMin;
    PlotWidth  = GraphWidth/GraphFraction;
    xlim([0 length(xList)+1]);
    ylim([0.5*(ParamMax + ParamMin - PlotWidth), 0.5*(ParamMax + ParamMin + PlotWidth)])

    title([num2str(PlotFrequencies(n)), ' Hz'], 'Interpreter', 'latex', 'FontSize', 20);
    if (abs(n-1) < 0.01)
      legend2 = legend('Simulation', 'Measurement', 'Interpreter', 'Latex', 'FontSize', 14)
      % Uncomment the following line to change the position of the legend. Choose either "north", "south", "east", "west", "northeast", "northwest", "southeast", "southwest" or "outside"
      %legend(legend2, "location", 'north')
    end
  end
else
  xList = 1:length(PlotReceivers);
  xTickLabels = {};
  for n = 1:length(PlotReceivers)
    xTickLabels{n} = ['Receiver ' num2str(PlotReceivers(n))];
  end

  figure(1)
  plot(xList, ParamSim(ReceiverIndices), 'ko', 'LineWidth', 2)
  hold on
  plot(xList, ParamMeas(ReceiverIndices), 'rx', 'LineWidth', 2)

  ParamMax = max(max(ParamSim(ReceiverIndices)), max(ParamMeas(ReceiverIndices)));
  ParamMin = min(min(ParamSim(ReceiverIndices)), min(ParamMeas(ReceiverIndices)));
  GraphWidth = ParamMax - ParamMin;
  PlotWidth  = GraphWidth/GraphFraction;
  xlim([0 length(xList)+1]);
  ylim([0.5*(ParamMax + ParamMin - PlotWidth), 0.5*(ParamMax + ParamMin + PlotWidth)])
  grid on

  ylabel(GetYLabel(ParameterName));
  set(gca, 'xtick', xList);
  set(gca, 'xticklabel',xTickLabels);
  set(gca, 'FontSize', 14)
  legend3 = legend('Simulation', 'Measurement', 'Interpreter', 'Latex', 'FontSize', 14)
end



