function [SourceList, ReceiverList, FrequencyList, ParamSim, ParamMeas, ParamJND, ParamExists] = ReadSimulatedAndMeasuredParameters(ParameterName, FileName, FileLocation)

%==============================================================================%
% Initialization                                                               %
%==============================================================================%

% Define the list of frequencies
NFrequency    = 8;
FrequencyList = [63, 125, 250, 500, 1000, 2000, 4000, 8000];

% Extract the file ID
FileID = fopen([FileLocation, '\', FileName], 'r');

% Translate the parameter name into a unique parameter tag
ParamExists = 'Yes';
if strcmp(ParameterName, 'EDT')
  ParameterTag   = 'EDT(s)';
  ParameterIsSTI = 'No';
elseif strcmp(ParameterName, 'T(20)')
  ParameterTag = 'T(20)(s)';
  ParameterIsSTI = 'No';
elseif strcmp(ParameterName, 'xi(T(20))')
  ParameterTag = ' ξ(T(20))(‰)';
  ParameterIsSTI = 'No';
elseif strcmp(ParameterName, 'T(30)')
  ParameterTag = 'T(30)(s)';
  ParameterIsSTI = 'No';
elseif strcmp(ParameterName, 'xi(T(30))')
  ParameterTag = ' ξ(T(30))(‰)';
  ParameterIsSTI = 'No';
elseif strcmp(ParameterName, 'Curvature')
  ParameterTag = 'Curvature(C)(%)';
  ParameterIsSTI = 'No';
elseif strcmp(ParameterName, 'Ts')
  ParameterTag = 'Ts(ms)';
  ParameterIsSTI = 'No';
elseif strcmp(ParameterName, 'G')
  ParameterTag = 'G(dB)';
  ParameterIsSTI = 'No';
elseif strcmp(ParameterName, 'G(early)')
  ParameterTag = 'G(early)(dB)';
  ParameterIsSTI = 'No';
elseif strcmp(ParameterName, 'G(late)')
  ParameterTag = 'G(late)(dB)';
  ParameterIsSTI = 'No';
elseif strcmp(ParameterName, 'C(80)')
  ParameterTag = 'C(80)(dB)';
  ParameterIsSTI = 'No';
elseif strcmp(ParameterName, 'MTI(corrected)')
  ParameterTag = 'MTI(corrected) simulated';
  ParameterIsSTI = 'No';
elseif strcmp(ParameterName, 'LF(80)')
  ParameterTag = 'LF(80) simulated';
  ParameterIsSTI = 'No';
elseif strcmp(ParameterName, 'LFC(80)')
  ParameterTag = 'LFC(80) simulated';
  ParameterIsSTI = 'No';
elseif strcmp(ParameterName, 'Diffusivity')
  ParameterTag = 'Diffusivity(ss)(dB)';
  ParameterIsSTI = 'No';
elseif strcmp(ParameterName, 'Echo(Dietsch)')
  ParameterTag = 'Echo(Dietsch) simulated';
  ParameterIsSTI = 'No';
elseif strcmp(ParameterName, 'STI')
  ParameterTag = 'STI simulated';
  ParameterIsSTI = 'Yes';
elseif strcmp(ParameterName, 'STI(Female)')
  ParameterTag = 'STI(Female) simulated';
  ParameterIsSTI = 'Yes';
elseif strcmp(ParameterName, 'STI(Male)')
  ParameterTag = 'STI(Male) simulated';
  ParameterIsSTI = 'Yes';
else
  disp('The chosen parameter does not exist!');
  disp('Please choose one from the list!')
  SourceList    = [];
  ReceiverList  = [];
  FrequencyList = [];
  ParamSim      = [];
  ParamMeas     = [];
  ParamJND      = [];
  ParamExists   = 'No';
  return;
end



%==============================================================================%
% Read the data file                                                           %
%==============================================================================%

% Read the list of sources
SourceList = [];
Line = fgetl(FileID);
while (~strncmpi(Line, 'Parameters ordered by position', 30))
  if strncmpi(Line, 'Source number', 13)
    SourceList = [SourceList, str2num(Line(15:end))];
  end
  Line = fgetl(FileID);
end


% Read the list of receivers
ReceiverList = [];
while (~strncmpi(Line, 'Simulated and measured parameters', 33))
  if strncmpi(Line, 'Receiver Number', 15)
    StartIndex = 18;
    StopIndex  = 19;
    while (Line(StopIndex) ~= ' ')
      StopIndex = StopIndex + 1;
    end
    ReceiverList = [ReceiverList, str2num(Line(StartIndex:StopIndex-1))];
  end
  Line = fgetl(FileID);
end


% Read the simulated and measured values of the parameter for each of the receivers
while (~strncmpi(Line, ParameterTag, length(ParameterTag)))
  Line = fgetl(FileID);
end
Line = fgetl(FileID);

if strcmpi(ParameterIsSTI, 'No')
  Param = zeros(length(ReceiverList), 3*NFrequency+2);
elseif strcmpi(ParameterIsSTI, 'Yes')
  Param = zeros(length(ReceiverList), 4);
end

for nReceiver = 1:length(ReceiverList)
  Line       = fgetl(FileID);
  StartIndex = 1;
  for nData = 1:length(Param(1,:))
    [Word, StartIndex] = ReadNextWordFromLine(Line, StartIndex);
    if (length(Word) > 1)
      Param(nReceiver, nData) = str2num(Word);
    else
      Param(nReceiver, nData) = nan;
    end
  end
end

if strcmpi(ParameterIsSTI, 'No')
  Param     = Param(:,2:end);
  ParamSim  = Param(:,1:NFrequency);
  ParamMeas = Param(:,NFrequency+1:2*NFrequency);
  ParamJND  = Param(:,2*NFrequency+1:3*NFrequency);
elseif strcmpi(ParameterIsSTI, 'Yes')
  Param     = Param(:,2:end);
  ParamSim  = Param(:,1);
  ParamMeas = Param(:,2);
  ParamJND  = Param(:,3);
end


% Close the file
fclose(FileID);



end
